diff --git a/rules.rules.events.yml b/rules.rules.events.yml
index 86ab55778666cf8d49f8f792c254068fc8763738..af45f8822d48b63bb50fe90f0a6b131515bf09e7 100644
--- a/rules.rules.events.yml
+++ b/rules.rules.events.yml
@@ -1,14 +1,14 @@
 rules_user_login:
   label: 'User has logged in'
   category: 'User'
-  context:
+  context_definitions:
     account:
       type: 'entity:user'
       label: 'Logged in user'
 rules_user_logout:
   label: 'User has logged out'
   category: 'User'
-  context:
+  context_definitions:
     account:
       type: 'entity:user'
       label: 'Logged out user'
@@ -44,7 +44,7 @@ rules_system_cron:
 rules_system_logger_event:
   label: 'System log entry is created'
   category: 'System'
-  context:
+  context_definitions:
     # @todo Create a TypedData logger-entry object: https://www.drupal.org/node/2625238
     logger_entry:
       type: 'any'
diff --git a/src/Context/Form/ContextFormTrait.php b/src/Context/Form/ContextFormTrait.php
index 51ee22961f56244fb49ffb4c6ddfc5c3393a2519..775b95b3e231f2c6d5d9e6c02e7e0cf08d15fb76 100644
--- a/src/Context/Form/ContextFormTrait.php
+++ b/src/Context/Form/ContextFormTrait.php
@@ -17,11 +17,11 @@ trait ContextFormTrait {
    * Provides the form part for a context parameter.
    */
   public function buildContextForm(array $form, FormStateInterface $form_state, $context_name, ContextDefinitionInterface $context_definition, array $configuration) {
-    $form['context'][$context_name] = [
+    $form['context_definitions'][$context_name] = [
       '#type' => 'fieldset',
       '#title' => $context_definition->getLabel(),
     ];
-    $form['context'][$context_name]['description'] = [
+    $form['context_definitions'][$context_name]['description'] = [
       '#markup' => $context_definition->getDescription(),
     ];
 
@@ -53,14 +53,14 @@ trait ContextFormTrait {
     else {
       $default_value = $context_definition->getDefaultValue();
     }
-    $form['context'][$context_name]['setting'] = [
+    $form['context_definitions'][$context_name]['setting'] = [
       '#type' => 'textfield',
       '#title' => $title,
       '#required' => $context_definition->isRequired(),
       '#default_value' => $default_value,
     ];
 
-    $element = &$form['context'][$context_name]['setting'];
+    $element = &$form['context_definitions'][$context_name]['setting'];
 
     if ($mode == ContextDefinitionInterface::ASSIGNMENT_RESTRICTION_SELECTOR) {
       $element['#description'] = $this->t("The data selector helps you drill down into the available data. <em>To make entity fields appear in the data selector, you may have to use the condition 'entity has field' (or 'content is of type').</em> More useful tips about data selection is available in <a href=':url'>the online documentation</a>.", [
@@ -87,7 +87,7 @@ trait ContextFormTrait {
     // button to switch between the two modes.
     if (empty($context_definition->getAssignmentRestriction())) {
       $value = $mode == ContextDefinitionInterface::ASSIGNMENT_RESTRICTION_SELECTOR ? $this->t('Switch to the direct input mode') : $this->t('Switch to data selection');
-      $form['context'][$context_name]['switch_button'] = [
+      $form['context_definitions'][$context_name]['switch_button'] = [
         '#type' => 'submit',
         '#name' => 'context_' . $context_name,
         '#attributes' => ['class' => ['rules-switch-button']],
@@ -115,8 +115,8 @@ trait ContextFormTrait {
    */
   protected function getContextConfigFromFormValues(FormStateInterface $form_state, array $context_definitions) {
     $context_config = ContextConfig::create();
-    if ($form_state->hasValue('context')) {
-      foreach ($form_state->getValue('context') as $context_name => $value) {
+    if ($form_state->hasValue('context_definitions')) {
+      foreach ($form_state->getValue('context_definitions') as $context_name => $value) {
         if ($form_state->get("context_$context_name") == ContextDefinitionInterface::ASSIGNMENT_RESTRICTION_SELECTOR) {
           $context_config->map($context_name, $value['setting']);
         }
diff --git a/src/Core/Annotation/Condition.php b/src/Core/Annotation/Condition.php
index c882e46f0810f39b92a218a303cdf5f1bf58b3e9..6d875cb12952798820bf1718c35ad09114650798 100644
--- a/src/Core/Annotation/Condition.php
+++ b/src/Core/Annotation/Condition.php
@@ -30,7 +30,7 @@ class Condition extends CoreConditionAnnotation {
    *     id = "my_module_user_is_blocked",
    *     label = @Translation("My User is blocked"),
    *     category = @Translation("User"),
-   *     context = {
+   *     context_definitions = {
    *       "user" = @ContextDefinition("entity:user",
    *         label = @Translation("User")
    *      ),
diff --git a/src/Core/RulesDefaultEventHandler.php b/src/Core/RulesDefaultEventHandler.php
index eea8115033b547e01f94f173feb33882adc96387..5faa36301be6279f23cb467878d7c8c855e4e8d6 100644
--- a/src/Core/RulesDefaultEventHandler.php
+++ b/src/Core/RulesDefaultEventHandler.php
@@ -18,7 +18,7 @@ class RulesDefaultEventHandler extends PluginBase implements RulesEventHandlerIn
     if ($this instanceof RulesConfigurableEventHandlerInterface) {
       $this->refineContextDefinitions();
     }
-    return !empty($definition['context']) ? $definition['context'] : [];
+    return !empty($definition['context_definitions']) ? $definition['context_definitions'] : [];
   }
 
   /**
diff --git a/src/Engine/RulesComponent.php b/src/Engine/RulesComponent.php
index caf9fe28cb37080e4e272c3297558c5b86283005..e7c74180f842f7b0553402a6a585e96830b64ea5 100644
--- a/src/Engine/RulesComponent.php
+++ b/src/Engine/RulesComponent.php
@@ -171,7 +171,7 @@ class RulesComponent {
       // @todo Correctly handle multiple events to intersect available context.
       // @todo Use setter injection for the service.
       $event_definition = \Drupal::service('plugin.manager.rules_event')->getDefinition($event_name);
-      foreach ($event_definition['context'] as $context_name => $context_definition) {
+      foreach ($event_definition['context_definitions'] as $context_name => $context_definition) {
         $this->addContextDefinition($context_name, $context_definition);
       }
     }
diff --git a/src/EventSubscriber/GenericEventSubscriber.php b/src/EventSubscriber/GenericEventSubscriber.php
index 5f3a4ec047117c550ed5e93cbfeba05ca549372d..4665eda9ff99d52a22ce2101fdd4eb279de46f06 100644
--- a/src/EventSubscriber/GenericEventSubscriber.php
+++ b/src/EventSubscriber/GenericEventSubscriber.php
@@ -105,7 +105,7 @@ class GenericEventSubscriber implements EventSubscriberInterface {
 
     // Setup the execution state.
     $state = ExecutionState::create();
-    foreach ($event_definition['context'] as $context_name => $context_definition) {
+    foreach ($event_definition['context_definitions'] as $context_name => $context_definition) {
       // If this is a GenericEvent get the context for the rule from the event
       // arguments.
       if ($event instanceof GenericEvent) {
diff --git a/src/Form/Expression/ActionForm.php b/src/Form/Expression/ActionForm.php
index 9165f0a3899cc556d2803b46b1f7c7f535338abf..c835766f16647364e0acb78951df46d87a78f019 100644
--- a/src/Form/Expression/ActionForm.php
+++ b/src/Form/Expression/ActionForm.php
@@ -87,7 +87,7 @@ class ActionForm implements ExpressionFormInterface {
 
     $context_definitions = $action->getContextDefinitions();
 
-    $form['context']['#tree'] = TRUE;
+    $form['context_definitions']['#tree'] = TRUE;
     foreach ($context_definitions as $context_name => $context_definition) {
       $form = $this->buildContextForm($form, $form_state, $context_name, $context_definition, $configuration);
     }
diff --git a/src/Form/Expression/ConditionForm.php b/src/Form/Expression/ConditionForm.php
index 9131d2c45684e77557c2fc12ee7a6b7a03b6dc9b..194a6079b75a6b2a0fde3d13f5a23a7e05349f78 100644
--- a/src/Form/Expression/ConditionForm.php
+++ b/src/Form/Expression/ConditionForm.php
@@ -89,7 +89,7 @@ class ConditionForm implements ExpressionFormInterface {
 
     $context_definitions = $condition->getContextDefinitions();
 
-    $form['context']['#tree'] = TRUE;
+    $form['context_definitions']['#tree'] = TRUE;
     foreach ($context_definitions as $context_name => $context_definition) {
       $form = $this->buildContextForm($form, $form_state, $context_name, $context_definition, $configuration);
     }
@@ -147,7 +147,7 @@ class ConditionForm implements ExpressionFormInterface {
     }
 
     $condition_definition = $this->conditionManager->getDefinition($condition_id);
-    $context_config = $this->getContextConfigFromFormValues($form_state, $condition_definition['context']);
+    $context_config = $this->getContextConfigFromFormValues($form_state, $condition_definition['context_definitions']);
 
     $configuration = $context_config->toArray();
     $configuration['condition_id'] = $form_state->get('condition_id');
diff --git a/src/Plugin/Condition/DataComparison.php b/src/Plugin/Condition/DataComparison.php
index edd97164b51992fc64d23ae70a1064674d8ca763..a67b0386262593665b8e744490e625d633ba7b47 100644
--- a/src/Plugin/Condition/DataComparison.php
+++ b/src/Plugin/Condition/DataComparison.php
@@ -11,7 +11,7 @@ use Drupal\rules\Core\RulesConditionBase;
  *   id = "rules_data_comparison",
  *   label = @Translation("Data comparison"),
  *   category = @Translation("Data"),
- *   context = {
+ *   context_definitions = {
  *     "data" = @ContextDefinition("any",
  *       label = @Translation("Data to compare"),
  *       description = @Translation("The data to be compared, specified by using a data selector, e.g. 'node.uid.entity.name.value'."),
@@ -85,9 +85,9 @@ class DataComparison extends RulesConditionBase {
    */
   public function refineContextDefinitions(array $selected_data) {
     if (isset($selected_data['data'])) {
-      $this->pluginDefinition['context']['value']->setDataType($selected_data['data']->getDataType());
+      $this->pluginDefinition['context_definitions']['value']->setDataType($selected_data['data']->getDataType());
       if ($this->getContextValue('operation') == 'IN') {
-        $this->pluginDefinition['context']['value']->setMultiple();
+        $this->pluginDefinition['context_definitions']['value']->setMultiple();
       }
     }
   }
diff --git a/src/Plugin/Condition/DataIsEmpty.php b/src/Plugin/Condition/DataIsEmpty.php
index e0ae83bf7a760d10b886ed397e9aff3c1067768d..6a1351585c2975cd283dbe324016f9a60f17da67 100644
--- a/src/Plugin/Condition/DataIsEmpty.php
+++ b/src/Plugin/Condition/DataIsEmpty.php
@@ -16,7 +16,7 @@ use Drupal\rules\Core\RulesConditionBase;
  *   id = "rules_data_is_empty",
  *   label = @Translation("Data value is empty"),
  *   category = @Translation("Data"),
- *   context = {
+ *   context_definitions = {
  *     "data" = @ContextDefinition("any",
  *       label = @Translation("Data to check"),
  *       description = @Translation("The data to be checked to be empty, specified by using a data selector, e.g. 'node.uid.entity.name.value'.")
diff --git a/src/Plugin/Condition/DataListContains.php b/src/Plugin/Condition/DataListContains.php
index cf8dd9af7441def48d72cdef6c92bcd18e4af5da..1e73f137f02e262cb81898dbb37a8d991f3281da 100644
--- a/src/Plugin/Condition/DataListContains.php
+++ b/src/Plugin/Condition/DataListContains.php
@@ -12,7 +12,7 @@ use Drupal\Core\Entity\EntityInterface;
  *   id = "rules_list_contains",
  *   label = @Translation("List contains item"),
  *   category = @Translation("Data"),
- *   context = {
+ *   context_definitions = {
  *     "list" = @ContextDefinition("list",
  *       label = @Translation("List"),
  *       description = @Translation("The list to be checked."),
diff --git a/src/Plugin/Condition/DataListCountIs.php b/src/Plugin/Condition/DataListCountIs.php
index c64a8eef9a9ab8126db450f1f05477e014000074..d04d622fbe6651ad647ae1c42f918cdce3757176 100644
--- a/src/Plugin/Condition/DataListCountIs.php
+++ b/src/Plugin/Condition/DataListCountIs.php
@@ -11,7 +11,7 @@ use Drupal\rules\Core\RulesConditionBase;
  *   id = "rules_list_count_is",
  *   label = @Translation("List count comparison"),
  *   category = @Translation("Data"),
- *   context = {
+ *   context_definitions = {
  *     "list" = @ContextDefinition("list",
  *       label = @Translation("List"),
  *       description = @Translation("A multi-valued data element to have its count compared, specified by using a data selector, eg 'node.uid.entity.roles'.")
diff --git a/src/Plugin/Condition/EntityHasField.php b/src/Plugin/Condition/EntityHasField.php
index 8d847c7591780e9f75ae66b32e956c212a2c9aab..e9aba7f8fbe6543298de16ebcec2b6a0c8fab461 100644
--- a/src/Plugin/Condition/EntityHasField.php
+++ b/src/Plugin/Condition/EntityHasField.php
@@ -12,7 +12,7 @@ use Drupal\rules\Core\RulesConditionBase;
  *   id = "rules_entity_has_field",
  *   label = @Translation("Entity has field"),
  *   category = @Translation("Entity"),
- *   context = {
+ *   context_definitions = {
  *     "entity" = @ContextDefinition("entity",
  *       label = @Translation("Entity"),
  *       description = @Translation("Specifies the entity for which to evaluate the condition."),
diff --git a/src/Plugin/Condition/EntityIsNew.php b/src/Plugin/Condition/EntityIsNew.php
index bd220e82c234c9e7ff9bed0237eb28aba389e150..fa103cc6ddfb5da4c68ce60c01890628df067ac0 100644
--- a/src/Plugin/Condition/EntityIsNew.php
+++ b/src/Plugin/Condition/EntityIsNew.php
@@ -12,7 +12,7 @@ use Drupal\rules\Core\RulesConditionBase;
  *   id = "rules_entity_is_new",
  *   label = @Translation("Entity is new"),
  *   category = @Translation("Entity"),
- *   context = {
+ *   context_definitions = {
  *     "entity" = @ContextDefinition("entity",
  *       label = @Translation("Entity"),
  *       description = @Translation("Specifies the entity for which to evaluate the condition."),
diff --git a/src/Plugin/Condition/EntityIsOfBundle.php b/src/Plugin/Condition/EntityIsOfBundle.php
index caca17dfd7f91f37ea1093c8ac1faa6c3ba83738..32f89a1fc7be2a265526122eccacf9f03c9707cb 100644
--- a/src/Plugin/Condition/EntityIsOfBundle.php
+++ b/src/Plugin/Condition/EntityIsOfBundle.php
@@ -12,7 +12,7 @@ use Drupal\rules\Core\RulesConditionBase;
  *   id = "rules_entity_is_of_bundle",
  *   label = @Translation("Entity is of bundle"),
  *   category = @Translation("Entity"),
- *   context = {
+ *   context_definitions = {
  *     "entity" = @ContextDefinition("entity",
  *       label = @Translation("Entity"),
  *       description = @Translation("Specifies the entity for which to evaluate the condition."),
diff --git a/src/Plugin/Condition/EntityIsOfType.php b/src/Plugin/Condition/EntityIsOfType.php
index 40bf4064f8b16b3126d2351679185b50093c1bc0..b3a999bd7a8288becde463f385962666214a6b3b 100644
--- a/src/Plugin/Condition/EntityIsOfType.php
+++ b/src/Plugin/Condition/EntityIsOfType.php
@@ -12,7 +12,7 @@ use Drupal\rules\Core\RulesConditionBase;
  *   id = "rules_entity_is_of_type",
  *   label = @Translation("Entity is of type"),
  *   category = @Translation("Entity"),
- *   context = {
+ *   context_definitions = {
  *     "entity" = @ContextDefinition("entity",
  *       label = @Translation("Entity"),
  *       description = @Translation("Specifies the entity for which to evaluate the condition."),
diff --git a/src/Plugin/Condition/NodeIsOfType.php b/src/Plugin/Condition/NodeIsOfType.php
index 1a833c27a015781281d1da8f20b80d87e5ec0396..3e1b79e47630ca98685304aef0a12e4b68cdcf45 100644
--- a/src/Plugin/Condition/NodeIsOfType.php
+++ b/src/Plugin/Condition/NodeIsOfType.php
@@ -12,7 +12,7 @@ use Drupal\rules\Core\RulesConditionBase;
  *   id = "rules_node_is_of_type",
  *   label = @Translation("Node is of type"),
  *   category = @Translation("Node"),
- *   context = {
+ *   context_definitions = {
  *     "node" = @ContextDefinition("entity:node",
  *       label = @Translation("Node"),
  *       description = @Translation("Specifies the node for which to evaluate the condition."),
diff --git a/src/Plugin/Condition/NodeIsPromoted.php b/src/Plugin/Condition/NodeIsPromoted.php
index bbd24ffa33298d638055ba66e213f5ffafea1a3b..ab13881c852c1bae61dbc5279e68cb5f8c0044a6 100644
--- a/src/Plugin/Condition/NodeIsPromoted.php
+++ b/src/Plugin/Condition/NodeIsPromoted.php
@@ -12,7 +12,7 @@ use Drupal\rules\Core\RulesConditionBase;
  *   id = "rules_node_is_promoted",
  *   label = @Translation("Node is promoted"),
  *   category = @Translation("Node"),
- *   context = {
+ *   context_definitions = {
  *     "node" = @ContextDefinition("entity:node",
  *       label = @Translation("Node"),
  *       description = @Translation("Specifies the node for which to evaluate the condition."),
diff --git a/src/Plugin/Condition/NodeIsPublished.php b/src/Plugin/Condition/NodeIsPublished.php
index 1e51d3e9d84c04ccf76c95744cc76abc08ec7bc5..c443f3acc610213f2dce35306b8b33c207f78504 100644
--- a/src/Plugin/Condition/NodeIsPublished.php
+++ b/src/Plugin/Condition/NodeIsPublished.php
@@ -12,7 +12,7 @@ use Drupal\rules\Core\RulesConditionBase;
  *   id = "rules_node_is_published",
  *   label = @Translation("Node is published"),
  *   category = @Translation("Node"),
- *   context = {
+ *   context_definitions = {
  *     "node" = @ContextDefinition("entity:node",
  *       label = @Translation("Node"),
  *       description = @Translation("Specifies the node for which to evaluate the condition."),
diff --git a/src/Plugin/Condition/NodeIsSticky.php b/src/Plugin/Condition/NodeIsSticky.php
index 682d4e3166a3f243790b1267cef3494b46dd15f8..87b02410e03452c612cd7e82360deb093c5d6dd0 100644
--- a/src/Plugin/Condition/NodeIsSticky.php
+++ b/src/Plugin/Condition/NodeIsSticky.php
@@ -12,7 +12,7 @@ use Drupal\rules\Core\RulesConditionBase;
  *   id = "rules_node_is_sticky",
  *   label = @Translation("Node is sticky"),
  *   category = @Translation("Node"),
- *   context = {
+ *   context_definitions = {
  *     "node" = @ContextDefinition("entity:node",
  *       label = @Translation("Node"),
  *       description = @Translation("Specifies the node for which to evaluate the condition."),
diff --git a/src/Plugin/Condition/PathAliasExists.php b/src/Plugin/Condition/PathAliasExists.php
index 7a20c0c65e8e7f0e51653a4ac55bd39ab6848b4d..4d912255eb591e81df77b4eefb16b877c53c7983 100644
--- a/src/Plugin/Condition/PathAliasExists.php
+++ b/src/Plugin/Condition/PathAliasExists.php
@@ -15,7 +15,7 @@ use Symfony\Component\DependencyInjection\ContainerInterface;
  *   id = "rules_path_alias_exists",
  *   label = @Translation("Path alias exists"),
  *   category = @Translation("Path"),
- *   context = {
+ *   context_definitions = {
  *     "alias" = @ContextDefinition("string",
  *       label = @Translation("Path alias"),
  *       description = @Translation("Specify the path alias to check for. For example, '/about' for an about page.")
diff --git a/src/Plugin/Condition/PathHasAlias.php b/src/Plugin/Condition/PathHasAlias.php
index cc423764430952fc05434dfe7256b70e6faefa64..bac6ec594f0f63736a42e5954ad6b8e4e94c4a44 100644
--- a/src/Plugin/Condition/PathHasAlias.php
+++ b/src/Plugin/Condition/PathHasAlias.php
@@ -15,7 +15,7 @@ use Symfony\Component\DependencyInjection\ContainerInterface;
  *   id = "rules_path_has_alias",
  *   label = @Translation("Path has alias"),
  *   category = @Translation("Path"),
- *   context = {
+ *   context_definitions = {
  *     "path" = @ContextDefinition("string",
  *       label = @Translation("Path"),
  *       description = @Translation("Specifies the existing path you wish to check. For example, '/node/28' or '/forum/1'.")
diff --git a/src/Plugin/Condition/TextComparison.php b/src/Plugin/Condition/TextComparison.php
index 136799d5994e8d87e4b266f6030c54d08118e2f8..dedb892b7ddd9adc6ba37b7d05576d59e80c8323 100644
--- a/src/Plugin/Condition/TextComparison.php
+++ b/src/Plugin/Condition/TextComparison.php
@@ -11,7 +11,7 @@ use Drupal\rules\Core\RulesConditionBase;
  *   id = "rules_text_comparison",
  *   label = @Translation("Text comparison"),
  *   category = @Translation("Data"),
- *   context = {
+ *   context_definitions = {
  *     "text" = @ContextDefinition("string",
  *       label = @Translation("Text"),
  *       description = @Translation("Specifies the text data to evaluate."),
diff --git a/src/Plugin/Condition/UserHasEntityFieldAccess.php b/src/Plugin/Condition/UserHasEntityFieldAccess.php
index 405ba17cce7444c9836129d38bae4e2b681deb2c..5ce297d694788263072604ed2b06194bbf40c0c0 100644
--- a/src/Plugin/Condition/UserHasEntityFieldAccess.php
+++ b/src/Plugin/Condition/UserHasEntityFieldAccess.php
@@ -16,7 +16,7 @@ use Symfony\Component\DependencyInjection\ContainerInterface;
  *   id = "rules_entity_field_access",
  *   label = @Translation("User has entity field access"),
  *   category = @Translation("User"),
- *   context = {
+ *   context_definitions = {
  *     "entity" = @ContextDefinition("entity",
  *       label = @Translation("Entity"),
  *       description = @Translation("Specifies the entity for which to evaluate the condition."),
diff --git a/src/Plugin/Condition/UserHasRole.php b/src/Plugin/Condition/UserHasRole.php
index 290c5e26333693bf6f57ff70a0f644d8a2fa1f50..ed006fff70665e1698f761d3bb5fc662cd9ea4bc 100644
--- a/src/Plugin/Condition/UserHasRole.php
+++ b/src/Plugin/Condition/UserHasRole.php
@@ -13,7 +13,7 @@ use Drupal\user\UserInterface;
  *   id = "rules_user_has_role",
  *   label = @Translation("User has role(s)"),
  *   category = @Translation("User"),
- *   context = {
+ *   context_definitions = {
  *     "user" = @ContextDefinition("entity:user",
  *       label = @Translation("User"),
  *       description = @Translation("Specifies the user account to check."),
diff --git a/src/Plugin/Condition/UserIsBlocked.php b/src/Plugin/Condition/UserIsBlocked.php
index 99693a9f819943b5af2590ff457cc3ae205a422f..35d98c616f3fd9571dc874d163449d3881e86a25 100644
--- a/src/Plugin/Condition/UserIsBlocked.php
+++ b/src/Plugin/Condition/UserIsBlocked.php
@@ -12,7 +12,7 @@ use Drupal\user\UserInterface;
  *   id = "rules_user_is_blocked",
  *   label = @Translation("User is blocked"),
  *   category = @Translation("User"),
- *   context = {
+ *   context_definitions = {
  *     "user" = @ContextDefinition("entity:user",
  *       label = @Translation("User"),
  *       description = @Translation("Specifies the user account to check.")
diff --git a/src/Plugin/RulesEvent/EntityDeleteDeriver.php b/src/Plugin/RulesEvent/EntityDeleteDeriver.php
index f046ab3e9d10230d628f9d17e31d6a5a527a82ae..5f9caf32d293a46479ec532d12936cdd3ae48795 100644
--- a/src/Plugin/RulesEvent/EntityDeleteDeriver.php
+++ b/src/Plugin/RulesEvent/EntityDeleteDeriver.php
@@ -57,7 +57,7 @@ class EntityDeleteDeriver extends DeriverBase implements ContainerDeriverInterfa
         'label' => $this->t('After deleting a @entity_type', ['@entity_type' => $entity_type->getSingularLabel()]),
         'category' => $entity_type->getLabel(),
         'entity_type_id' => $entity_type_id,
-        'context' => [
+        'context_definitions' => [
           $entity_type_id => [
             'type' => "entity:$entity_type_id",
             'label' => $entity_type->getLabel(),
diff --git a/src/Plugin/RulesEvent/EntityInsertDeriver.php b/src/Plugin/RulesEvent/EntityInsertDeriver.php
index 017b4c7223085f00fefc08025c5482b244cf317a..c36bb6178f1dec8e575d33d717baa185bf27c7a6 100644
--- a/src/Plugin/RulesEvent/EntityInsertDeriver.php
+++ b/src/Plugin/RulesEvent/EntityInsertDeriver.php
@@ -57,7 +57,7 @@ class EntityInsertDeriver extends DeriverBase implements ContainerDeriverInterfa
         'label' => $this->t('After saving a new @entity_type', ['@entity_type' => $entity_type->getSingularLabel()]),
         'category' => $entity_type->getLabel(),
         'entity_type_id' => $entity_type_id,
-        'context' => [
+        'context_definitions' => [
           $entity_type_id => [
             'type' => "entity:$entity_type_id",
             'label' => $entity_type->getLabel(),
diff --git a/src/Plugin/RulesEvent/EntityPresaveDeriver.php b/src/Plugin/RulesEvent/EntityPresaveDeriver.php
index 215e12cc8452edbaab8553088fac4de82b5d9883..7e98f504ea1840f73ff9e72a1f2c757580046ff5 100644
--- a/src/Plugin/RulesEvent/EntityPresaveDeriver.php
+++ b/src/Plugin/RulesEvent/EntityPresaveDeriver.php
@@ -57,7 +57,7 @@ class EntityPresaveDeriver extends DeriverBase implements ContainerDeriverInterf
         'label' => $this->t('Before saving a @entity_type', ['@entity_type' => $entity_type->getSingularLabel()]),
         'category' => $entity_type->getLabel(),
         'entity_type_id' => $entity_type_id,
-        'context' => [
+        'context_definitions' => [
           $entity_type_id => [
             'type' => "entity:$entity_type_id",
             'label' => $entity_type->getLabel(),
diff --git a/src/Plugin/RulesEvent/EntityUpdateDeriver.php b/src/Plugin/RulesEvent/EntityUpdateDeriver.php
index fcce20802b4b916fdda207e17c4c691fb08a5b18..5b32402a2537b7e514c5d2d0301b531027d8dc52 100644
--- a/src/Plugin/RulesEvent/EntityUpdateDeriver.php
+++ b/src/Plugin/RulesEvent/EntityUpdateDeriver.php
@@ -57,7 +57,7 @@ class EntityUpdateDeriver extends DeriverBase implements ContainerDeriverInterfa
         'label' => $this->t('After updating a @entity_type', ['@entity_type' => $entity_type->getSingularLabel()]),
         'category' => $entity_type->getLabel(),
         'entity_type_id' => $entity_type_id,
-        'context' => [
+        'context_definitions' => [
           $entity_type_id => [
             'type' => "entity:$entity_type_id",
             'label' => $entity_type->getLabel(),
diff --git a/src/Plugin/RulesEvent/EntityViewDeriver.php b/src/Plugin/RulesEvent/EntityViewDeriver.php
index 0a63d3259c2cf39928d79986046ecd2518dca443..79cf6e04e2cc090d298b7af9d44283bdd540f8e1 100644
--- a/src/Plugin/RulesEvent/EntityViewDeriver.php
+++ b/src/Plugin/RulesEvent/EntityViewDeriver.php
@@ -57,7 +57,7 @@ class EntityViewDeriver extends DeriverBase implements ContainerDeriverInterface
         'label' => $this->t('@entity_type is viewed', ['@entity_type' => $entity_type->getLabel()]),
         'category' => $entity_type->getLabel(),
         'entity_type_id' => $entity_type_id,
-        'context' => [
+        'context_definitions' => [
           $entity_type_id => [
             'type' => "entity:$entity_type_id",
             'label' => $entity_type->getLabel(),
diff --git a/tests/modules/rules_test/src/Plugin/Condition/TestTextCondition.php b/tests/modules/rules_test/src/Plugin/Condition/TestTextCondition.php
index 2e4f85a4c70bbbaa617ca40389b5468f1244bb70..4b19fef195c6f343ae5270a76c4739e087398124 100644
--- a/tests/modules/rules_test/src/Plugin/Condition/TestTextCondition.php
+++ b/tests/modules/rules_test/src/Plugin/Condition/TestTextCondition.php
@@ -11,7 +11,7 @@ use Drupal\rules\Core\RulesConditionBase;
  *   id = "rules_test_string_condition",
  *   label = @Translation("Test condition using a string"),
  *   category = @Translation("Tests"),
- *   context = {
+ *   context_definitions = {
  *     "text" = @ContextDefinition("string",
  *       label = @Translation("Text to compare")
  *     ),
diff --git a/tests/src/Functional/ConfigureAndExecuteTest.php b/tests/src/Functional/ConfigureAndExecuteTest.php
index e19704b31451e9a8c86d909d2f98944d5b5c263c..9ce561c07925c6253d55dbfaa4c8c71f7f7317b3 100644
--- a/tests/src/Functional/ConfigureAndExecuteTest.php
+++ b/tests/src/Functional/ConfigureAndExecuteTest.php
@@ -73,16 +73,16 @@ class ConfigureAndExecuteTest extends RulesBrowserTestBase {
     $this->fillField('Condition', 'rules_data_comparison');
     $this->pressButton('Continue');
 
-    $this->fillField('context[data][setting]', 'node.title.0.value');
-    $this->fillField('context[value][setting]', 'Test title');
+    $this->fillField('context_definitions[data][setting]', 'node.title.0.value');
+    $this->fillField('context_definitions[value][setting]', 'Test title');
     $this->pressButton('Save');
 
     $this->clickLink('Add action');
     $this->fillField('Action', 'rules_system_message');
     $this->pressButton('Continue');
 
-    $this->fillField('context[message][setting]', 'Title matched "Test title"!');
-    $this->fillField('context[type][setting]', 'status');
+    $this->fillField('context_definitions[message][setting]', 'Title matched "Test title"!');
+    $this->fillField('context_definitions[type][setting]', 'status');
     $this->pressButton('Save');
 
     // One more save to permanently store the rule.
@@ -140,7 +140,7 @@ class ConfigureAndExecuteTest extends RulesBrowserTestBase {
     $this->fillField('Condition', 'rules_node_is_of_type');
     $this->pressButton('Continue');
 
-    $this->fillField('context[node][setting]', 'node');
+    $this->fillField('context_definitions[node][setting]', 'node');
 
     $suboptimal_user_input = [
       "  \r\nwhitespace at beginning of input\r\n",
@@ -161,7 +161,7 @@ class ConfigureAndExecuteTest extends RulesBrowserTestBase {
       "terminator nr\n\r",
       "whitespace at end of input\r\n        \r\n",
     ];
-    $this->fillField('context[types][setting]', implode($suboptimal_user_input));
+    $this->fillField('context_definitions[types][setting]', implode($suboptimal_user_input));
     $this->pressButton('Save');
 
     // One more save to permanently store the rule.
@@ -239,26 +239,26 @@ class ConfigureAndExecuteTest extends RulesBrowserTestBase {
     // Edit condition 1, assert that the switch button is shown for value and
     // that the default entry field is regular text entry not a selector.
     $this->drupalGet('admin/config/workflow/rules/reactions/edit/test_rule/edit/' . $condition1->getUuid());
-    $assert->buttonExists('edit-context-value-switch-button');
-    $assert->elementExists('xpath', '//input[@id="edit-context-value-setting" and not(contains(@class, "rules-autocomplete"))]');
+    $assert->buttonExists('edit-context-definitions-value-switch-button');
+    $assert->elementExists('xpath', '//input[@id="edit-context-definitions-value-setting" and not(contains(@class, "rules-autocomplete"))]');
 
     // Edit condition 2, assert that the switch button is NOT shown for node
     // and that the entry field is a selector with class rules-autocomplete.
     $this->drupalGet('admin/config/workflow/rules/reactions/edit/test_rule/edit/' . $condition2->getUuid());
-    $assert->buttonNotExists('edit-context-node-switch-button');
-    $assert->elementExists('xpath', '//input[@id="edit-context-node-setting" and contains(@class, "rules-autocomplete")]');
+    $assert->buttonNotExists('edit-context-definitions-node-switch-button');
+    $assert->elementExists('xpath', '//input[@id="edit-context-definitions-node-setting" and contains(@class, "rules-autocomplete")]');
 
     // Edit action 1, assert that the switch button is shown for message and
     // that the default entry field is a regular text entry not a selector.
     $this->drupalGet('admin/config/workflow/rules/reactions/edit/test_rule/edit/' . $action1->getUuid());
-    $assert->buttonExists('edit-context-message-switch-button');
-    $assert->elementExists('xpath', '//input[@id="edit-context-message-setting" and not(contains(@class, "rules-autocomplete"))]');
+    $assert->buttonExists('edit-context-definitions-message-switch-button');
+    $assert->elementExists('xpath', '//input[@id="edit-context-definitions-message-setting" and not(contains(@class, "rules-autocomplete"))]');
 
     // Edit action 2, assert that the switch button is NOT shown for type and
     // that the entry field is a regular text entry not a selector.
     $this->drupalGet('admin/config/workflow/rules/reactions/edit/test_rule/edit/' . $action2->getUuid());
-    $assert->buttonNotExists('edit-context-type-switch-button');
-    $assert->elementExists('xpath', '//input[@id="edit-context-type-setting" and not(contains(@class, "rules-autocomplete"))]');
+    $assert->buttonNotExists('edit-context-definitions-type-switch-button');
+    $assert->elementExists('xpath', '//input[@id="edit-context-definitions-type-setting" and not(contains(@class, "rules-autocomplete"))]');
   }
 
 }
diff --git a/tests/src/Functional/RulesUiEmbedTest.php b/tests/src/Functional/RulesUiEmbedTest.php
index 4bbeadd06ece1d08dd64fac98f7d24e4e2baab5a..872bbebf4c59b4ec249db5e2230cf00fbe27f22e 100644
--- a/tests/src/Functional/RulesUiEmbedTest.php
+++ b/tests/src/Functional/RulesUiEmbedTest.php
@@ -31,8 +31,8 @@ class RulesUiEmbedTest extends RulesBrowserTestBase {
     $this->clickLink('Add condition');
     $this->fillField('Condition', 'rules_data_comparison');
     $this->pressButton('Continue');
-    $this->fillField('context[data][setting]', '@user.current_user_context:current_user.uid.value');
-    $this->fillField('context[value][setting]', '234');
+    $this->fillField('context_definitions[data][setting]', '@user.current_user_context:current_user.uid.value');
+    $this->fillField('context_definitions[value][setting]', '234');
     $this->pressButton('Save');
 
     // Now the condition should be listed. Try editing it.
@@ -40,9 +40,9 @@ class RulesUiEmbedTest extends RulesBrowserTestBase {
     $assert = $this->assertSession();
     $assert->pageTextContains('Data comparison');
     $this->clickLink('Edit');
-    $assert->fieldValueEquals('context[data][setting]', '@user.current_user_context:current_user.uid.value');
-    $assert->fieldValueEquals('context[value][setting]', '234');
-    $this->fillField('context[value][setting]', '123');
+    $assert->fieldValueEquals('context_definitions[data][setting]', '@user.current_user_context:current_user.uid.value');
+    $assert->fieldValueEquals('context_definitions[value][setting]', '234');
+    $this->fillField('context_definitions[value][setting]', '123');
     $this->pressButton('Save');
     $assert->pageTextContains('Data comparison');
 
diff --git a/tests/src/Functional/TempStorageTest.php b/tests/src/Functional/TempStorageTest.php
index 3d79b62e621efb8d33827a0eeba58869f0de6dfe..69aa84e93186d6a1382493b0ca832eef34093951 100644
--- a/tests/src/Functional/TempStorageTest.php
+++ b/tests/src/Functional/TempStorageTest.php
@@ -43,7 +43,7 @@ class TempStorageTest extends RulesBrowserTestBase {
     $this->fillField('Condition', 'rules_node_is_promoted');
     $this->pressButton('Continue');
 
-    $this->fillField('context[node][setting]', 'node');
+    $this->fillField('context_definitions[node][setting]', 'node');
     $this->pressButton('Save');
 
     /** @var \Drupal\Tests\WebAssert $assert */
diff --git a/tests/src/Functional/UiPageTest.php b/tests/src/Functional/UiPageTest.php
index 328e88bc4c979b274917421576c4eff074d53a9d..6c808bee3ea57fed1eac24e397de885a2f98a4cd 100644
--- a/tests/src/Functional/UiPageTest.php
+++ b/tests/src/Functional/UiPageTest.php
@@ -66,7 +66,7 @@ class UiPageTest extends RulesBrowserTestBase {
     $this->fillField('Condition', 'rules_node_is_promoted');
     $this->pressButton('Continue');
 
-    $this->fillField('context[node][setting]', 'node');
+    $this->fillField('context_definitions[node][setting]', 'node');
     $this->pressButton('Save');
 
     $assert->statusCodeEquals(200);
@@ -87,7 +87,7 @@ class UiPageTest extends RulesBrowserTestBase {
     $this->fillField('Condition', 'rules_node_is_promoted');
     $this->pressButton('Continue');
 
-    $this->fillField('context[node][setting]', 'node');
+    $this->fillField('context_definitions[node][setting]', 'node');
     $this->pressButton('Save');
 
     /** @var \Drupal\Tests\WebAssert $assert */
@@ -183,9 +183,9 @@ class UiPageTest extends RulesBrowserTestBase {
     $this->pressButton('Switch to data selection');
     $this->pressButton('Switch to the direct input mode');
 
-    $this->fillField('context[to][setting]', 'klausi@example.com');
-    $this->fillField('context[subject][setting]', 'subject');
-    $this->fillField('context[message][setting]', 'message');
+    $this->fillField('context_definitions[to][setting]', 'klausi@example.com');
+    $this->fillField('context_definitions[subject][setting]', 'subject');
+    $this->fillField('context_definitions[message][setting]', 'message');
     $this->pressButton('Save');
 
     /** @var \Drupal\Tests\WebAssert $assert */
diff --git a/tests/src/Unit/Integration/Condition/ConditionManagerTest.php b/tests/src/Unit/Integration/Condition/ConditionManagerTest.php
index 7b3b14a6cd33e82585764893fb25ae1d9e236a0e..a6c625eefb81269ba91f505b8a697ccdbd7d24f5 100644
--- a/tests/src/Unit/Integration/Condition/ConditionManagerTest.php
+++ b/tests/src/Unit/Integration/Condition/ConditionManagerTest.php
@@ -20,8 +20,8 @@ class ConditionManagerTest extends RulesIntegrationTestBase {
     $definitions = $this->conditionManager->getDefinitions();
     // Make sure all context definitions are using the class provided by Rules.
     foreach ($definitions as $definition) {
-      if (!empty($definition['context'])) {
-        foreach ($definition['context'] as $context_definition) {
+      if (!empty($definition['context_definitions'])) {
+        foreach ($definition['context_definitions'] as $context_definition) {
           $this->assertInstanceOf(ContextDefinitionInterface::class, $context_definition);
         }
       }
diff --git a/tests/src/Unit/Integration/Event/EntityDeleteTest.php b/tests/src/Unit/Integration/Event/EntityDeleteTest.php
index bd753c7d2bdbf03b40490f1860f4796727211239..9516d668793c29ecefd697610162a3ec710f435f 100644
--- a/tests/src/Unit/Integration/Event/EntityDeleteTest.php
+++ b/tests/src/Unit/Integration/Event/EntityDeleteTest.php
@@ -17,7 +17,7 @@ class EntityDeleteTest extends EventTestBase {
   public function testEventMetadata() {
     $plugin_definition = $this->eventManager->getDefinition('rules_entity_delete:test');
     $this->assertSame('After deleting a test', (string) $plugin_definition['label']);
-    $context_definition = $plugin_definition['context']['test'];
+    $context_definition = $plugin_definition['context_definitions']['test'];
     $this->assertSame('entity:test', $context_definition->getDataType());
     $this->assertSame('Test', $context_definition->getLabel());
   }
diff --git a/tests/src/Unit/Integration/Event/EntityInsertTest.php b/tests/src/Unit/Integration/Event/EntityInsertTest.php
index efea6427c9a636cd615d0bbf9c1dd05d22c9958d..2c7475934415e982294001cae835064d2b2d874b 100644
--- a/tests/src/Unit/Integration/Event/EntityInsertTest.php
+++ b/tests/src/Unit/Integration/Event/EntityInsertTest.php
@@ -17,7 +17,7 @@ class EntityInsertTest extends EventTestBase {
   public function testEventMetadata() {
     $plugin_definition = $this->eventManager->getDefinition('rules_entity_insert:test');
     $this->assertSame('After saving a new test', (string) $plugin_definition['label']);
-    $context_definition = $plugin_definition['context']['test'];
+    $context_definition = $plugin_definition['context_definitions']['test'];
     $this->assertSame('entity:test', $context_definition->getDataType());
     $this->assertSame('Test', $context_definition->getLabel());
   }
diff --git a/tests/src/Unit/Integration/Event/EntityPresaveTest.php b/tests/src/Unit/Integration/Event/EntityPresaveTest.php
index 8567bff3f7ca108bdf7c55037b71f0a489f84d9a..18e4c2e45864ab000474f3ef11008d8064eed47a 100644
--- a/tests/src/Unit/Integration/Event/EntityPresaveTest.php
+++ b/tests/src/Unit/Integration/Event/EntityPresaveTest.php
@@ -17,12 +17,12 @@ class EntityPresaveTest extends EventTestBase {
   public function testEventMetadata() {
     $plugin_definition = $this->eventManager->getDefinition('rules_entity_presave:test');
     $this->assertSame('Before saving a test', (string) $plugin_definition['label']);
-    $context_definition = $plugin_definition['context']['test'];
+    $context_definition = $plugin_definition['context_definitions']['test'];
     $this->assertSame('entity:test', $context_definition->getDataType());
     $this->assertSame('Test', $context_definition->getLabel());
 
     // Also check that there is a context for the original entity.
-    $context_definition = $plugin_definition['context']['test_unchanged'];
+    $context_definition = $plugin_definition['context_definitions']['test_unchanged'];
     $this->assertSame('entity:test', $context_definition->getDataType());
     $this->assertSame('Unchanged Test', (string) $context_definition->getLabel());
   }
diff --git a/tests/src/Unit/Integration/Event/EntityUpdateTest.php b/tests/src/Unit/Integration/Event/EntityUpdateTest.php
index 8ae2947e35fe9759d2006e3587eb2e13d2c44da1..66bedcfee878abdbac81c0e9d68e31442db3572a 100644
--- a/tests/src/Unit/Integration/Event/EntityUpdateTest.php
+++ b/tests/src/Unit/Integration/Event/EntityUpdateTest.php
@@ -17,12 +17,12 @@ class EntityUpdateTest extends EventTestBase {
   public function testEventMetadata() {
     $plugin_definition = $this->eventManager->getDefinition('rules_entity_update:test');
     $this->assertSame('After updating a test', (string) $plugin_definition['label']);
-    $context_definition = $plugin_definition['context']['test'];
+    $context_definition = $plugin_definition['context_definitions']['test'];
     $this->assertSame('entity:test', $context_definition->getDataType());
     $this->assertSame('Test', $context_definition->getLabel());
 
     // Also check that there is a context for the original entity.
-    $context_definition = $plugin_definition['context']['test_unchanged'];
+    $context_definition = $plugin_definition['context_definitions']['test_unchanged'];
     $this->assertSame('entity:test', $context_definition->getDataType());
     $this->assertSame('Unchanged Test', (string) $context_definition->getLabel());
   }
diff --git a/tests/src/Unit/Integration/Event/EntityViewTest.php b/tests/src/Unit/Integration/Event/EntityViewTest.php
index 14376e42318e78deb2c9be04a9633d57b72e9e1a..737533ee0f3c51e17a51a04460d0c659f35dd223 100644
--- a/tests/src/Unit/Integration/Event/EntityViewTest.php
+++ b/tests/src/Unit/Integration/Event/EntityViewTest.php
@@ -17,7 +17,7 @@ class EntityViewTest extends EventTestBase {
   public function testEventMetadata() {
     $plugin_definition = $this->eventManager->getDefinition('rules_entity_view:test');
     $this->assertSame('Test is viewed', (string) $plugin_definition['label']);
-    $context_definition = $plugin_definition['context']['test'];
+    $context_definition = $plugin_definition['context_definitions']['test'];
     $this->assertSame('entity:test', $context_definition->getDataType());
     $this->assertSame('Test', $context_definition->getLabel());
   }
diff --git a/src/Core/RulesEventManager.php b/src/Core/RulesEventManager.php
index 49123755c88eedf0af796c5dff11a3f7f78e91d9..3c002d537eb077caf500d0c9aead2806b27a6f1d 100644
--- a/src/Core/RulesEventManager.php
+++ b/src/Core/RulesEventManager.php
@@ -66,12 +66,12 @@ class RulesEventManager extends DefaultPluginManager implements CategorizingPlug
    */
   public function processDefinition(&$definition, $plugin_id) {
     parent::processDefinition($definition, $plugin_id);
-    if (!isset($definition['context'])) {
-      $definition['context'] = [];
+    if (!isset($definition['context_definitions'])) {
+      $definition['context_definitions'] = [];
     }
-    // Convert the flat context arrays into ContextDefinition objects.
-    foreach ($definition['context'] as $context_name => $values) {
-      $definition['context'][$context_name] = ContextDefinition::createFromArray($values);
+    // Convert the flat context_definitions arrays to ContextDefinition objects.
+    foreach ($definition['context_definitions'] as $context_name => $values) {
+      $definition['context_definitions'][$context_name] = ContextDefinition::createFromArray($values);
     }
   }
 